# Model-Checker Instructions

> TODO: expand these instructions

## Contents

This package includes the following templates:
  - `README.md` to document usage and changes.
  - `__init__.py` to expose definitions.
  - `examples.py` defines a number of examples to test.
  - `operators.py` defines the primitive and derived operators.
  - `semantic.py` defines the default semantics for the operators included.

## Basic Usage

> TO BE CONTINUED...

## Testing

Run `pytest` from the project directory to quickly evaluate whether the examples included in `examples.py` return the expected result.

